aria

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ActiveDescendant

func ActiveDescendant(id string) htm.Mod

ActiveDescendant identifies the currently active element when focus is on a composite widget.

func Atomic

func Atomic(v ...bool) htm.Mod

Atomic indicates whether assistive technologies will present all changes.

func Autocomplete

func Autocomplete(v string) htm.Mod

Autocomplete indicates autocomplete behavior.

func Busy

func Busy(v ...bool) htm.Mod

Busy indicates an element is being modified.

func Checked

func Checked(v ...bool) htm.Mod

Checked indicates the current "checked" state of checkboxes, radio buttons, and other widgets.

func ColCount

func ColCount(v int) htm.Mod

ColCount defines the total number of columns.

func ColIndex

func ColIndex(v int) htm.Mod

ColIndex defines an element's column index.

func ColSpan

func ColSpan(v int) htm.Mod

ColSpan defines the number of columns spanned by a cell.

func Controls

func Controls(id string) htm.Mod

Controls identifies the element (or elements) whose contents or presence are controlled by the current element.

func Current

func Current(v string) htm.Mod

Current indicates the element that represents the current item within a container or set of related elements.

func DescribedBy

func DescribedBy(id string) htm.Mod

DescribedBy identifies the element (or elements) that describes the object.

func Details

func Details(id string) htm.Mod

Details identifies the element that provides a detailed, extended description for the object.

func Disabled

func Disabled(v ...bool) htm.Mod

Disabled indicates that the element is perceivable but disabled.

func Expanded

func Expanded(v ...bool) htm.Mod

Expanded indicates whether the element, or another grouping element it controls, is currently expanded or collapsed.

func FlowTo

func FlowTo(id string) htm.Mod

FlowTo identifies the next element (or elements) in an alternate reading order.

func HasPopup

func HasPopup(v string) htm.Mod

HasPopup indicates the availability and type of interactive popup element.

func Hidden

func Hidden(v ...bool) htm.Mod

Hidden indicates whether the element is exposed to an accessibility API.

func Invalid

func Invalid(v htm.TypedValue) htm.Mod

Invalid indicates the entered value does not conform to the expected format.

func KeyShortcuts

func KeyShortcuts(v string) htm.Mod

KeyShortcuts indicates keyboard shortcuts.

func Label

func Label(v string) htm.Mod

Label defines a string value that labels the current element.

func LabelledBy

func LabelledBy(id string) htm.Mod

LabelledBy identifies the element (or elements) that labels the current element.

func Level

func Level(v int) htm.Mod

Level defines the hierarchical level of an element.

func Live

func Live(v string) htm.Mod

Live indicates that an element will be updated.

func Modal(v ...bool) htm.Mod

Modal indicates whether an element is modal when displayed.

func Multiline

func Multiline(v ...bool) htm.Mod

Multiline indicates whether a text box accepts multiple lines.

func Multiselectable

func Multiselectable(v ...bool) htm.Mod

Multiselectable indicates that the user may select more than one item.

func Orientation

func Orientation(v string) htm.Mod

Orientation indicates whether the element's orientation is horizontal or vertical.

func Owns

func Owns(id string) htm.Mod

Owns identifies an element (or elements) in order to define a visual, functional, or contextual parent/child relationship.

func Placeholder

func Placeholder(v string) htm.Mod

Placeholder defines a short hint (a word or short phrase) intended to aid the user with data entry.

func PosInSet

func PosInSet(v int) htm.Mod

PosInSet defines an element's position in the set.

func Pressed

func Pressed(v ...bool) htm.Mod

Pressed indicates the current "pressed" state of toggle buttons.

func ReadOnly

func ReadOnly(v ...bool) htm.Mod

ReadOnly indicates that the element is not editable, but is otherwise operable.

func Relevant

func Relevant(v string) htm.Mod

Relevant indicates what notifications the user agent will trigger.

func Required

func Required(v ...bool) htm.Mod

Required indicates that user input is required on the element before a form may be submitted.

func RoleDescription

func RoleDescription(v string) htm.Mod

RoleDescription defines a human-readable, author-localized description for the role of an element.

func RowCount

func RowCount(v int) htm.Mod

RowCount defines the total number of rows.

func RowIndex

func RowIndex(v int) htm.Mod

RowIndex defines an element's row index.

func RowSpan

func RowSpan(v int) htm.Mod

RowSpan defines the number of rows spanned.

func Selected

func Selected(v ...bool) htm.Mod

Selected indicates the current "selected" state of various widgets.

func SetActiveDescendant

func SetActiveDescendant(n *htm.Node, id string)

SetActiveDescendant identifies the currently active element when focus is on a composite widget.

func SetAtomic

func SetAtomic(n *htm.Node, v ...bool)

SetAtomic indicates whether assistive technologies will present all changes.

func SetAutocomplete

func SetAutocomplete(n *htm.Node, v string)

SetAutocomplete indicates autocomplete behavior.

func SetBusy

func SetBusy(n *htm.Node, v ...bool)

SetBusy indicates an element is being modified.

func SetChecked

func SetChecked(n *htm.Node, v ...bool)

SetChecked indicates the current "checked" state of checkboxes, radio buttons, and other widgets.

func SetColCount

func SetColCount(n *htm.Node, v int)

SetColCount defines the total number of columns.

func SetColIndex

func SetColIndex(n *htm.Node, v int)

SetColIndex defines an element's column index.

func SetColSpan

func SetColSpan(n *htm.Node, v int)

SetColSpan defines the number of columns spanned by a cell.

func SetControls

func SetControls(n *htm.Node, id string)

SetControls identifies the element (or elements) whose contents or presence are controlled by the current element.

func SetCurrent

func SetCurrent(n *htm.Node, v string)

SetCurrent indicates the element that represents the current item within a container or set of related elements.

func SetDescribedBy

func SetDescribedBy(n *htm.Node, id string)

SetDescribedBy identifies the element (or elements) that describes the object.

func SetDetails

func SetDetails(n *htm.Node, id string)

SetDetails identifies the element that provides a detailed, extended description for the object.

func SetDisabled

func SetDisabled(n *htm.Node, v ...bool)

SetDisabled indicates that the element is perceivable but disabled.

func SetExpanded

func SetExpanded(n *htm.Node, v ...bool)

SetExpanded indicates whether the element, or another grouping element it controls, is currently expanded or collapsed.

func SetFlowTo

func SetFlowTo(n *htm.Node, id string)

SetFlowTo identifies the next element (or elements) in an alternate reading order.

func SetHasPopup

func SetHasPopup(n *htm.Node, v string)

SetHasPopup indicates the availability and type of interactive popup element.

func SetHidden

func SetHidden(n *htm.Node, v ...bool)

SetHidden indicates whether the element is exposed to an accessibility API.

func SetInvalid

func SetInvalid(n *htm.Node, v htm.TypedValue)

SetInvalid indicates the entered value does not conform to the expected format.

func SetKeyShortcuts

func SetKeyShortcuts(n *htm.Node, v string)

SetKeyShortcuts indicates keyboard shortcuts.

func SetLabel

func SetLabel(n *htm.Node, v string)

SetLabel defines a string value that labels the current element.

func SetLabelledBy

func SetLabelledBy(n *htm.Node, id string)

SetLabelledBy identifies the element (or elements) that labels the current element.

func SetLevel

func SetLevel(n *htm.Node, v int)

SetLevel defines the hierarchical level of an element.

func SetLive

func SetLive(n *htm.Node, v string)

SetLive indicates that an element will be updated.

func SetModal

func SetModal(n *htm.Node, v ...bool)

SetModal indicates whether an element is modal when displayed.

func SetMultiline

func SetMultiline(n *htm.Node, v ...bool)

SetMultiline indicates whether a text box accepts multiple lines.

func SetMultiselectable

func SetMultiselectable(n *htm.Node, v ...bool)

SetMultiselectable indicates that the user may select more than one item.

func SetOrientation

func SetOrientation(n *htm.Node, v string)

SetOrientation indicates whether the element's orientation is horizontal or vertical.

func SetOwns

func SetOwns(n *htm.Node, id string)

SetOwns identifies an element (or elements) in order to define a visual, functional, or contextual parent/child relationship.

func SetPlaceholder

func SetPlaceholder(n *htm.Node, v string)

SetPlaceholder defines a short hint (a word or short phrase) intended to aid the user with data entry.

func SetPosInSet

func SetPosInSet(n *htm.Node, v int)

SetPosInSet defines an element's position in the set.

func SetPressed

func SetPressed(n *htm.Node, v ...bool)

SetPressed indicates the current "pressed" state of toggle buttons.

func SetReadOnly

func SetReadOnly(n *htm.Node, v ...bool)

SetReadOnly indicates that the element is not editable, but is otherwise operable.

func SetRelevant

func SetRelevant(n *htm.Node, v string)

SetRelevant indicates what notifications the user agent will trigger.

func SetRequired

func SetRequired(n *htm.Node, v ...bool)

SetRequired indicates that user input is required on the element before a form may be submitted.

func SetRoleDescription

func SetRoleDescription(n *htm.Node, v string)

SetRoleDescription defines a human-readable, author-localized description for the role of an element.

func SetRowCount

func SetRowCount(n *htm.Node, v int)

SetRowCount defines the total number of rows.

func SetRowIndex

func SetRowIndex(n *htm.Node, v int)

SetRowIndex defines an element's row index.

func SetRowSpan

func SetRowSpan(n *htm.Node, v int)

SetRowSpan defines the number of rows spanned.

func SetSelected

func SetSelected(n *htm.Node, v ...bool)

SetSelected indicates the current "selected" state of various widgets.

func SetSetSize

func SetSetSize(n *htm.Node, v int)

SetSetSize defines the number of items in the set.

func SetSize

func SetSize(v int) htm.Mod

SetSize defines the number of items in the set.

func SetSort

func SetSort(n *htm.Node, v string)

SetSort indicates if items are sorted.

func SetValueMax

func SetValueMax(n *htm.Node, v float64)

SetValueMax defines the maximum allowed value for a range widget.

func SetValueMin

func SetValueMin(n *htm.Node, v float64)

SetValueMin defines the minimum allowed value for a range widget.

func SetValueNow

func SetValueNow(n *htm.Node, v float64)

SetValueNow defines the current value for a range widget.

func SetValueText

func SetValueText(n *htm.Node, v string)

SetValueText defines the human readable text alternative of aria-valuenow for a range widget.

func Sort

func Sort(v string) htm.Mod

Sort indicates if items are sorted.

func ValueMax

func ValueMax(v float64) htm.Mod

ValueMax defines the maximum allowed value for a range widget.

func ValueMin

func ValueMin(v float64) htm.Mod

ValueMin defines the minimum allowed value for a range widget.

func ValueNow

func ValueNow(v float64) htm.Mod

ValueNow defines the current value for a range widget.

func ValueText

func ValueText(v string) htm.Mod

ValueText defines the human readable text alternative of aria-valuenow for a range widget.

Types

This section is empty.

Jump to