Documentation
¶
Index ¶
- func Boost(value ...bool) htm.Mod
- func Confirm(msg string) htm.Mod
- func Delete(url string) htm.Mod
- func Disable(v ...bool) htm.Mod
- func Disinherit(v string) htm.Mod
- func Encoding(v string) htm.Mod
- func Ext(extensions string) htm.Mod
- func Get(url string) htm.Mod
- func Headers(v htm.TypedValue) htm.Mod
- func History(v bool) htm.Mod
- func HistoryElt() htm.Mod
- func Include(selector string) htm.Mod
- func Indicator(selector string) htm.Mod
- func On(event string, js string) htm.Mod
- func Params(v string) htm.Mod
- func Patch(url string) htm.Mod
- func Post(url string) htm.Mod
- func Preserve(v ...bool) htm.Mod
- func PushURL(v string) htm.Mod
- func Put(url string) htm.Mod
- func ReplaceURL(v string) htm.Mod
- func Request(v htm.TypedValue) htm.Mod
- func Select(selector string) htm.Mod
- func SelectOOB(selector string) htm.Mod
- func SetBoost(n *htm.Node, value ...bool)
- func SetConfirm(n *htm.Node, msg string)
- func SetDelete(n *htm.Node, url string)
- func SetDisable(n *htm.Node, v ...bool)
- func SetDisinherit(n *htm.Node, v string)
- func SetEncoding(n *htm.Node, v string)
- func SetExt(n *htm.Node, extensions string)
- func SetGet(n *htm.Node, url string)
- func SetHeaders(n *htm.Node, v htm.TypedValue)
- func SetHistory(n *htm.Node, v bool)
- func SetHistoryElt(n *htm.Node)
- func SetInclude(n *htm.Node, selector string)
- func SetIndicator(n *htm.Node, selector string)
- func SetOn(n *htm.Node, event string, js string)
- func SetParams(n *htm.Node, v string)
- func SetPatch(n *htm.Node, url string)
- func SetPost(n *htm.Node, url string)
- func SetPreserve(n *htm.Node, v ...bool)
- func SetPushURL(n *htm.Node, v string)
- func SetPut(n *htm.Node, url string)
- func SetReplaceURL(n *htm.Node, v string)
- func SetRequest(n *htm.Node, v htm.TypedValue)
- func SetSelect(n *htm.Node, selector string)
- func SetSelectOOB(n *htm.Node, selector string)
- func SetSwap(n *htm.Node, strategy string)
- func SetSwapOOB(n *htm.Node, v string)
- func SetSync(n *htm.Node, selector string)
- func SetTarget(n *htm.Node, selector string)
- func SetTrigger(n *htm.Node, trigger string)
- func SetValidate(n *htm.Node, v ...bool)
- func SetVals(n *htm.Node, v htm.TypedValue)
- func Swap(strategy string) htm.Mod
- func SwapOOB(v string) htm.Mod
- func Sync(selector string) htm.Mod
- func Target(selector string) htm.Mod
- func Trigger(trigger string) htm.Mod
- func Validate(v ...bool) htm.Mod
- func Vals(v htm.TypedValue) htm.Mod
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Disinherit ¶
Disinherit allows to control the inheritance of htmx attributes.
func Encoding ¶
Encoding allows to switch the request encoding from the usual application/x-www-form-urlencoded to multipart/form-data.
func Headers ¶
func Headers(v htm.TypedValue) htm.Mod
Headers adds to the headers that will be submitted with the request. Typically accepts a JSON object.
func History ¶
History prevents sensitive data from being saved to the history cache. Usually used as hx-history="false".
func HistoryElt ¶
HistoryElt specifies the element to snapshot and restore during history navigation.
func Indicator ¶
Indicator specifies the element that is indicated during the request (e.g. a loading spinner).
func Params ¶
Params filters the parameters that will be submitted with a request. Values: "*", "none", "not <list>", or "<list>".
func Preserve ¶
Preserve specifies that an element should be kept invariant across requests (e.g. video players).
func PushURL ¶
PushURL pushes a new URL into the browser location history. Accepts: "true", "false", or a URL string.
func ReplaceURL ¶
ReplaceURL replaces the current URL in the browser location history. Accepts: "true", "false", or a URL string.
func Request ¶
func Request(v htm.TypedValue) htm.Mod
Request allows to configure various aspects of the request. Typically accepts a JSON object.
func SetConfirm ¶
SetConfirm sets the hx-confirm attribute on the node.
func SetDisable ¶
SetDisable sets the hx-disable attribute on the node.
func SetDisinherit ¶
SetDisinherit sets the hx-disinherit attribute on the node.
func SetEncoding ¶
SetEncoding sets the hx-encoding attribute on the node.
func SetHeaders ¶
func SetHeaders(n *htm.Node, v htm.TypedValue)
SetHeaders sets the hx-headers attribute on the node.
func SetHistory ¶
SetHistory sets the hx-history attribute on the node.
func SetHistoryElt ¶
SetHistoryElt sets the hx-history-elt attribute on the node.
func SetInclude ¶
SetInclude sets the hx-include attribute on the node.
func SetIndicator ¶
SetIndicator sets the hx-indicator attribute on the node.
func SetPreserve ¶
SetPreserve sets the hx-preserve attribute on the node.
func SetPushURL ¶
SetPushURL sets the hx-push-url attribute on the node.
func SetReplaceURL ¶
SetReplaceURL sets the hx-replace-url attribute on the node.
func SetRequest ¶
func SetRequest(n *htm.Node, v htm.TypedValue)
SetRequest sets the hx-request attribute on the node.
func SetSelectOOB ¶
SetSelectOOB sets the hx-select-oob attribute on the node.
func SetSwapOOB ¶
SetSwapOOB sets the hx-swap-oob attribute on the node.
func SetTrigger ¶
SetTrigger sets the hx-trigger attribute on the node.
func SetValidate ¶
SetValidate sets the hx-validate attribute on the node.
func SetVals ¶
func SetVals(n *htm.Node, v htm.TypedValue)
SetVals sets the hx-vals attribute on the node.
func SwapOOB ¶
SwapOOB allows to specify that some content in a response should be swapped into the DOM somewhere other than the target.
Types ¶
This section is empty.