Documentation
¶
Index ¶
- func ActiveDescendant(id string) htm.Mod
- func Atomic(v ...bool) htm.Mod
- func Autocomplete(v string) htm.Mod
- func Busy(v ...bool) htm.Mod
- func Checked(v ...bool) htm.Mod
- func ColCount(v int) htm.Mod
- func ColIndex(v int) htm.Mod
- func ColSpan(v int) htm.Mod
- func Controls(id string) htm.Mod
- func Current(v string) htm.Mod
- func DescribedBy(id string) htm.Mod
- func Details(id string) htm.Mod
- func Disabled(v ...bool) htm.Mod
- func Expanded(v ...bool) htm.Mod
- func FlowTo(id string) htm.Mod
- func HasPopup(v string) htm.Mod
- func Hidden(v ...bool) htm.Mod
- func Invalid(v htm.TypedValue) htm.Mod
- func KeyShortcuts(v string) htm.Mod
- func Label(v string) htm.Mod
- func LabelledBy(id string) htm.Mod
- func Level(v int) htm.Mod
- func Live(v string) htm.Mod
- func Modal(v ...bool) htm.Mod
- func Multiline(v ...bool) htm.Mod
- func Multiselectable(v ...bool) htm.Mod
- func Orientation(v string) htm.Mod
- func Owns(id string) htm.Mod
- func Placeholder(v string) htm.Mod
- func PosInSet(v int) htm.Mod
- func Pressed(v ...bool) htm.Mod
- func ReadOnly(v ...bool) htm.Mod
- func Relevant(v string) htm.Mod
- func Required(v ...bool) htm.Mod
- func RoleDescription(v string) htm.Mod
- func RowCount(v int) htm.Mod
- func RowIndex(v int) htm.Mod
- func RowSpan(v int) htm.Mod
- func Selected(v ...bool) htm.Mod
- func SetActiveDescendant(n *htm.Node, id string)
- func SetAtomic(n *htm.Node, v ...bool)
- func SetAutocomplete(n *htm.Node, v string)
- func SetBusy(n *htm.Node, v ...bool)
- func SetChecked(n *htm.Node, v ...bool)
- func SetColCount(n *htm.Node, v int)
- func SetColIndex(n *htm.Node, v int)
- func SetColSpan(n *htm.Node, v int)
- func SetControls(n *htm.Node, id string)
- func SetCurrent(n *htm.Node, v string)
- func SetDescribedBy(n *htm.Node, id string)
- func SetDetails(n *htm.Node, id string)
- func SetDisabled(n *htm.Node, v ...bool)
- func SetExpanded(n *htm.Node, v ...bool)
- func SetFlowTo(n *htm.Node, id string)
- func SetHasPopup(n *htm.Node, v string)
- func SetHidden(n *htm.Node, v ...bool)
- func SetInvalid(n *htm.Node, v htm.TypedValue)
- func SetKeyShortcuts(n *htm.Node, v string)
- func SetLabel(n *htm.Node, v string)
- func SetLabelledBy(n *htm.Node, id string)
- func SetLevel(n *htm.Node, v int)
- func SetLive(n *htm.Node, v string)
- func SetModal(n *htm.Node, v ...bool)
- func SetMultiline(n *htm.Node, v ...bool)
- func SetMultiselectable(n *htm.Node, v ...bool)
- func SetOrientation(n *htm.Node, v string)
- func SetOwns(n *htm.Node, id string)
- func SetPlaceholder(n *htm.Node, v string)
- func SetPosInSet(n *htm.Node, v int)
- func SetPressed(n *htm.Node, v ...bool)
- func SetReadOnly(n *htm.Node, v ...bool)
- func SetRelevant(n *htm.Node, v string)
- func SetRequired(n *htm.Node, v ...bool)
- func SetRoleDescription(n *htm.Node, v string)
- func SetRowCount(n *htm.Node, v int)
- func SetRowIndex(n *htm.Node, v int)
- func SetRowSpan(n *htm.Node, v int)
- func SetSelected(n *htm.Node, v ...bool)
- func SetSetSize(n *htm.Node, v int)
- func SetSize(v int) htm.Mod
- func SetSort(n *htm.Node, v string)
- func SetValueMax(n *htm.Node, v float64)
- func SetValueMin(n *htm.Node, v float64)
- func SetValueNow(n *htm.Node, v float64)
- func SetValueText(n *htm.Node, v string)
- func Sort(v string) htm.Mod
- func ValueMax(v float64) htm.Mod
- func ValueMin(v float64) htm.Mod
- func ValueNow(v float64) htm.Mod
- func ValueText(v string) htm.Mod
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ActiveDescendant ¶
ActiveDescendant identifies the currently active element when focus is on a composite widget.
func Autocomplete ¶
Autocomplete indicates autocomplete behavior.
func Checked ¶
Checked indicates the current "checked" state of checkboxes, radio buttons, and other widgets.
func Controls ¶
Controls identifies the element (or elements) whose contents or presence are controlled by the current element.
func Current ¶
Current indicates the element that represents the current item within a container or set of related elements.
func DescribedBy ¶
DescribedBy identifies the element (or elements) that describes the object.
func Details ¶
Details identifies the element that provides a detailed, extended description for the object.
func Expanded ¶
Expanded indicates whether the element, or another grouping element it controls, is currently expanded or collapsed.
func Invalid ¶
func Invalid(v htm.TypedValue) htm.Mod
Invalid indicates the entered value does not conform to the expected format.
func LabelledBy ¶
LabelledBy identifies the element (or elements) that labels the current element.
func Multiselectable ¶
Multiselectable indicates that the user may select more than one item.
func Orientation ¶
Orientation indicates whether the element's orientation is horizontal or vertical.
func Owns ¶
Owns identifies an element (or elements) in order to define a visual, functional, or contextual parent/child relationship.
func Placeholder ¶
Placeholder defines a short hint (a word or short phrase) intended to aid the user with data entry.
func Required ¶
Required indicates that user input is required on the element before a form may be submitted.
func RoleDescription ¶
RoleDescription defines a human-readable, author-localized description for the role of an element.
func SetActiveDescendant ¶
SetActiveDescendant identifies the currently active element when focus is on a composite widget.
func SetAutocomplete ¶
SetAutocomplete indicates autocomplete behavior.
func SetChecked ¶
SetChecked indicates the current "checked" state of checkboxes, radio buttons, and other widgets.
func SetColCount ¶
SetColCount defines the total number of columns.
func SetColIndex ¶
SetColIndex defines an element's column index.
func SetColSpan ¶
SetColSpan defines the number of columns spanned by a cell.
func SetControls ¶
SetControls identifies the element (or elements) whose contents or presence are controlled by the current element.
func SetCurrent ¶
SetCurrent indicates the element that represents the current item within a container or set of related elements.
func SetDescribedBy ¶
SetDescribedBy identifies the element (or elements) that describes the object.
func SetDetails ¶
SetDetails identifies the element that provides a detailed, extended description for the object.
func SetDisabled ¶
SetDisabled indicates that the element is perceivable but disabled.
func SetExpanded ¶
SetExpanded indicates whether the element, or another grouping element it controls, is currently expanded or collapsed.
func SetHasPopup ¶
SetHasPopup indicates the availability and type of interactive popup element.
func SetInvalid ¶
func SetInvalid(n *htm.Node, v htm.TypedValue)
SetInvalid indicates the entered value does not conform to the expected format.
func SetKeyShortcuts ¶
SetKeyShortcuts indicates keyboard shortcuts.
func SetLabelledBy ¶
SetLabelledBy identifies the element (or elements) that labels the current element.
func SetMultiline ¶
SetMultiline indicates whether a text box accepts multiple lines.
func SetMultiselectable ¶
SetMultiselectable indicates that the user may select more than one item.
func SetOrientation ¶
SetOrientation indicates whether the element's orientation is horizontal or vertical.
func SetOwns ¶
SetOwns identifies an element (or elements) in order to define a visual, functional, or contextual parent/child relationship.
func SetPlaceholder ¶
SetPlaceholder defines a short hint (a word or short phrase) intended to aid the user with data entry.
func SetPosInSet ¶
SetPosInSet defines an element's position in the set.
func SetPressed ¶
SetPressed indicates the current "pressed" state of toggle buttons.
func SetReadOnly ¶
SetReadOnly indicates that the element is not editable, but is otherwise operable.
func SetRelevant ¶
SetRelevant indicates what notifications the user agent will trigger.
func SetRequired ¶
SetRequired indicates that user input is required on the element before a form may be submitted.
func SetRoleDescription ¶
SetRoleDescription defines a human-readable, author-localized description for the role of an element.
func SetRowCount ¶
SetRowCount defines the total number of rows.
func SetRowSpan ¶
SetRowSpan defines the number of rows spanned.
func SetSelected ¶
SetSelected indicates the current "selected" state of various widgets.
func SetSetSize ¶
SetSetSize defines the number of items in the set.
func SetValueMax ¶
SetValueMax defines the maximum allowed value for a range widget.
func SetValueMin ¶
SetValueMin defines the minimum allowed value for a range widget.
func SetValueNow ¶
SetValueNow defines the current value for a range widget.
func SetValueText ¶
SetValueText defines the human readable text alternative of aria-valuenow for a range widget.
Types ¶
This section is empty.